@@ -32,6 +32,7 @@
 
 #include <kedittoolbar.h>
 #include <ksharedconfig.h>
+#include <kswitchlanguagedialog_p.h>
 #include <kconfiggroup.h>
 #include <kxmlguibuilder.h>
 #include <kxmlguiclient.h>
@@ -53,7 +54,7 @@ static void createXmlFile(QFile &file, int version, int flags, const QByteArray
 {
     const QByteArray xml =
         "<?xml version = '1.0'?>\n"
-        "<!DOCTYPE gui SYSTEM \"kpartgui.dtd\">\n"
+        "<!DOCTYPE " + toplevelTag + " SYSTEM \"kpartgui.dtd\">\n"
         "<" + toplevelTag + " version=\"" + QByteArray::number(version) + "\" name=\"foo\" >\n"
         "<MenuBar>\n";
     file.write(xml);
@@ -101,7 +102,7 @@ static void createXmlFile(QFile &file, int version, int flags, const QByteArray
 static void clickApply(KEditToolBar *dialog)
 {
     QDialogButtonBox *box = dialog->findChild<QDialogButtonBox *>();
-    Q_ASSERT(box != 0);
+    Q_ASSERT(box != nullptr);
     box->button(QDialogButtonBox::Apply)->setEnabled(true);
     box->button(QDialogButtonBox::Apply)->click();
 }
@@ -129,7 +130,7 @@ void KXmlGui_UnitTest::testFindVersionNumber_data()
                                  "<gui version=\"3\" name=\"foo\"/>\n" << "3";
     QTest::newRow("two digits") <<
                                 "<?xml version = '1.0'?>\n"
-                                "<kpartgui version=\"42\" name=\"foo\"/>\n" << "42";
+                                "<gui version=\"42\" name=\"foo\"/>\n" << "42";
     QTest::newRow("with spaces") << // as found in dirfilterplugin.rc for instance
                                  "<?xml version = '1.0'?>\n"
                                  "<gui version = \"1\" name=\"foo\"/>\n" << "1";
@@ -137,10 +138,10 @@ void KXmlGui_UnitTest::testFindVersionNumber_data()
                                 "<?xml version = '1.0'?>\n"
                                 "<gui version = \"0.2\" name=\"foo\"/>\n" << QString() /*error*/;
     QTest::newRow("with a comment") << // as found in kmail.rc
-                                    "<!DOCTYPE kpartgui>\n"
+                                    "<!DOCTYPE gui>\n"
                                     "<!-- This file should be synchronized with kmail_part.rc to provide\n"
                                     "the same menu entries at the same place in KMail and Kontact  -->\n"
-                                    "<kpartgui version=\"452\" name=\"kmmainwin\">\n" << "452";
+                                    "<gui version=\"452\" name=\"kmmainwin\">\n" << "452";
 }
 
 void KXmlGui_UnitTest::testFindVersionNumber()
@@ -173,12 +174,12 @@ void KXmlGui_UnitTest::testVersionHandlerSameVersion()
     KXmlGuiVersionHandler versionHandler(files);
     QCOMPARE(versionHandler.finalFile(), firstFile);
     QString finalDoc = versionHandler.finalDocument();
-    QVERIFY(finalDoc.startsWith("<?xml"));
+    QVERIFY(finalDoc.startsWith(QStringLiteral("<?xml")));
     // Check that the shortcuts defined by the user were kept
-    QVERIFY(finalDoc.contains("<ActionProperties>"));
-    QVERIFY(finalDoc.contains("sidebartng"));
+    QVERIFY(finalDoc.contains(QStringLiteral("<ActionProperties>")));
+    QVERIFY(finalDoc.contains(QStringLiteral("sidebartng")));
     // Check that the toolbars modified by the user were kept
-    QVERIFY(finalDoc.contains("<Action name=\"home\""));
+    QVERIFY(finalDoc.contains(QStringLiteral("<Action name=\"home\"")));
 
     QVERIFY(userFile.open());
     const QString userFileContents = QString::fromUtf8(userFile.readAll());
@@ -195,7 +196,7 @@ void KXmlGui_UnitTest::testVersionHandlerNewVersionNothingKept()
     QMap<QString, int> fileToVersionMap; // makes QCOMPARE failures more readable than just temp filenames
 
     QDir().mkpath(QStandardPaths::writableLocation(QStandardPaths::DataLocation));
-    QFile fileV2(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "testui.rc");
+    QFile fileV2(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + QStringLiteral("testui.rc"));
     QVERIFY2(fileV2.open(QIODevice::WriteOnly), qPrintable(fileV2.fileName()));
     createXmlFile(fileV2, 2, NoFlags);
     fileToVersionMap.insert(fileV2.fileName(), 2);
@@ -223,8 +224,8 @@ void KXmlGui_UnitTest::testVersionHandlerNewVersionNothingKept()
     KXmlGuiVersionHandler versionHandler(files);
     QCOMPARE(fileToVersionMap.value(versionHandler.finalFile()), 5);
     QString finalDoc = versionHandler.finalDocument();
-    QVERIFY(finalDoc.startsWith("<?xml"));
-    QVERIFY(finalDoc.contains("version=\"5\""));
+    QVERIFY(finalDoc.startsWith(QStringLiteral("<?xml")));
+    QVERIFY(finalDoc.contains(QStringLiteral("version=\"5\"")));
 
     QVERIFY(fileV5.open());
     const QString fileV5Contents = QString::fromUtf8(fileV5.readAll());
@@ -239,7 +240,7 @@ void KXmlGui_UnitTest::testVersionHandlerNewVersionUserChanges()
     QMap<QString, int> fileToVersionMap; // makes QCOMPARE failures more readable than just temp filenames
 
     // local file
-    QFile fileV2(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "testui.rc");
+    QFile fileV2(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + QStringLiteral("testui.rc"));
     QVERIFY(fileV2.open(QIODevice::WriteOnly));
     createXmlFile(fileV2, 2, AddActionProperties | AddModifiedToolBars);
     fileToVersionMap.insert(fileV2.fileName(), 2);
@@ -271,15 +272,15 @@ void KXmlGui_UnitTest::testVersionHandlerNewVersionUserChanges()
     QCOMPARE(fileToVersionMap.value(versionHandler.finalFile()), 2);
     const QString finalDoc = versionHandler.finalDocument();
     //qDebug() << finalDoc;
-    QVERIFY(finalDoc.startsWith("<?xml"));
-    QVERIFY(finalDoc.contains("version=\"5\""));
+    QVERIFY(finalDoc.startsWith(QStringLiteral("<?xml")));
+    QVERIFY(finalDoc.contains(QStringLiteral("version=\"5\"")));
     // Check that the shortcuts defined by the user were kept
-    QVERIFY(finalDoc.contains("<ActionProperties>"));
-    QVERIFY(finalDoc.contains("sidebartng"));
+    QVERIFY(finalDoc.contains(QStringLiteral("<ActionProperties>")));
+    QVERIFY(finalDoc.contains(QStringLiteral("sidebartng")));
     // Check that the menus modified by the app are still there
-    QVERIFY(finalDoc.contains("<Action name=\"file_open\""));
+    QVERIFY(finalDoc.contains(QStringLiteral("<Action name=\"file_open\"")));
     // Check that the toolbars modified by the user were kept
-    QVERIFY(finalDoc.contains("<Action name=\"home\""));
+    QVERIFY(finalDoc.contains(QStringLiteral("<Action name=\"home\"")));
 }
 
 static QStringList collectMenuNames(KXMLGUIFactory &factory)
@@ -295,7 +296,7 @@ static QStringList collectMenuNames(KXMLGUIFactory &factory)
 void debugActions(const QList<QAction *> &actions)
 {
     Q_FOREACH (QAction *action, actions) {
-        qDebug() << (action->isSeparator() ? QString("separator") : action->objectName());
+        qDebug() << (action->isSeparator() ? QString::fromLatin1("separator") : action->objectName());
     }
 }
 
@@ -306,7 +307,7 @@ static void checkActions(const QList<QAction *> &actions, const QStringList &exp
             break;
         QAction *action = actions.at(i);
         if (action->isSeparator()) {
-            QCOMPARE(QString("separator"), expectedActions[i]);
+            QCOMPARE(QStringLiteral("separator"), expectedActions[i]);
         } else {
             QCOMPARE(action->objectName(), expectedActions[i]);
         }
@@ -377,8 +378,8 @@ void KXmlGui_UnitTest::testPartMerging()
     qDebug() << "Now merging the part";
 
     const QByteArray partXml =
-        "<!DOCTYPE kpartgui SYSTEM \"kpartgui.dtd\">\n"
-        "<kpartgui version=\"1\" name=\"part\" >\n"
+        "<!DOCTYPE gui SYSTEM \"kpartgui.dtd\">\n"
+        "<gui version=\"1\" name=\"part\" >\n"
         "<MenuBar>\n"
         " <Menu name=\"go\"><text>&amp;Go</text>\n"
         "  <Action name=\"go_previous\" group=\"before_merge\"/>\n"
@@ -397,7 +398,7 @@ void KXmlGui_UnitTest::testPartMerging()
         "  <Action name=\"other_file_action\"/>\n"
         " </Menu>\n"
         "</MenuBar>\n"
-        "</kpartgui>\n";
+        "</gui>\n";
 
     TestGuiClient partClient(partXml);
     partClient.createActions(QStringList() << QStringLiteral("go_previous") << QStringLiteral("go_next") << QStringLiteral("first_page") <<
@@ -607,8 +608,8 @@ void KXmlGui_UnitTest::testUiStandardsMerging()
 
     const QDomDocument domDocument = client.domDocument();
     const QDomElement docElem = domDocument.documentElement();
-    QCOMPARE(docElem.attribute("name"), QString("foo")); // not standard_containers from ui_standards.rc
-    QCOMPARE(docElem.attribute("version"), QString("1")); // not standard_containers from ui_standards.rc
+    QCOMPARE(docElem.attribute(QStringLiteral("name")), QStringLiteral("foo")); // not standard_containers from ui_standards.rc
+    QCOMPARE(docElem.attribute(QStringLiteral("version")), QStringLiteral("1")); // not standard_containers from ui_standards.rc
 
     KMainWindow mainWindow;
     KXMLGUIBuilder builder(&mainWindow);
@@ -664,7 +665,7 @@ void KXmlGui_UnitTest::testActionListAndSeparator()
     action2->setObjectName(QStringLiteral("action2"));
     const QList<QAction *> actionList = { action1, action2 };
     client.plugActionList(QStringLiteral("view_groups_list"), actionList);
-    QCOMPARE(QKeySequence::listToString(action1->shortcuts()), QString("Ctrl+2"));
+    QCOMPARE(QKeySequence::listToString(action1->shortcuts()), QStringLiteral("Ctrl+2"));
 
     const QStringList expectedActionsOneList = {
         QStringLiteral("action1"),
@@ -722,7 +723,7 @@ void KXmlGui_UnitTest::testHiddenToolBar()
         "</ToolBar>\n"
         "</gui>\n";
     KConfigGroup cg(KSharedConfig::openConfig(), "testHiddenToolBar");
-    TestXmlGuiWindow mainWindow(xml);
+    TestXmlGuiWindow mainWindow(xml, "kxmlgui_unittest.rc");
     mainWindow.setAutoSaveSettings(cg);
     mainWindow.createActions(QStringList() << QStringLiteral("go_up"));
     mainWindow.createGUI();
@@ -731,7 +732,7 @@ void KXmlGui_UnitTest::testHiddenToolBar()
     QVERIFY(mainToolBar->isHidden());
 
     KXMLGUIFactory *factory = mainWindow.guiFactory();
-    QVERIFY(!factory->container("visibleToolBar", &mainWindow)->isHidden());
+    QVERIFY(!factory->container(QStringLiteral("visibleToolBar"), &mainWindow)->isHidden());
     KToolBar *hiddenToolBar = qobject_cast<KToolBar *>(factory->container(QStringLiteral("hiddenToolBar"), &mainWindow));
     qDebug() << hiddenToolBar;
     QVERIFY(hiddenToolBar->isHidden());
@@ -741,7 +742,7 @@ void KXmlGui_UnitTest::testHiddenToolBar()
     // KEditToolBar loads the stuff in showEvent...
     QShowEvent ev; qApp->sendEvent(&editToolBar, &ev);
     clickApply(&editToolBar);
-    QVERIFY(qobject_cast<KToolBar *>(factory->container("hiddenToolBar", &mainWindow))->isHidden());
+    QVERIFY(qobject_cast<KToolBar *>(factory->container(QStringLiteral("hiddenToolBar"), &mainWindow))->isHidden());
 
     mainWindow.close();
 }
@@ -765,7 +766,7 @@ void KXmlGui_UnitTest::testAutoSaveSettings()
     {
         // do not interfere with the "toolbarVisibility" unit test
         KConfigGroup cg(KSharedConfig::openConfig(), "testAutoSaveSettings");
-        TestXmlGuiWindow mw(xml);
+        TestXmlGuiWindow mw(xml, "kxmlgui_unittest.rc");
         mw.show();
         mw.setAutoSaveSettings(cg);
 
@@ -800,7 +801,7 @@ void KXmlGui_UnitTest::testAutoSaveSettings()
 
     {
         KConfigGroup cg(KSharedConfig::openConfig(), "testAutoSaveSettings");
-        TestXmlGuiWindow mw2(xml);
+        TestXmlGuiWindow mw2(xml, "kxmlgui_unittest.rc");
         mw2.show();
         mw2.setAutoSaveSettings(cg);
         QTest::qWait(200);
@@ -844,29 +845,29 @@ void KXmlGui_UnitTest::testDeletedContainers() // deleted="true"
         "</ToolBar>\n"
         "</gui>\n";
     KConfigGroup cg(KSharedConfig::openConfig(), "testDeletedToolBar");
-    TestXmlGuiWindow mainWindow(xml);
+    TestXmlGuiWindow mainWindow(xml, "kxmlgui_unittest.rc");
     mainWindow.setAutoSaveSettings(cg);
     mainWindow.createActions(QStringList() << QStringLiteral("go_up") << QStringLiteral("file_new") << QStringLiteral("game_new"));
     mainWindow.createGUI();
     KXMLGUIFactory *factory = mainWindow.guiFactory();
 
     //qDebug() << "containers:" << factory->containers("ToolBar");
-    QVERIFY(!factory->container("mainToolBar", &mainWindow));
-    QVERIFY(!factory->container("visibleToolBar", &mainWindow)->isHidden());
-    QVERIFY(!factory->container("deletedToolBar", &mainWindow));
-    QVERIFY(factory->container("file", &mainWindow)); // File menu was created
-    QVERIFY(!factory->container("game", &mainWindow)); // Game menu was not created
+    QVERIFY(!factory->container(QStringLiteral("mainToolBar"), &mainWindow));
+    QVERIFY(!factory->container(QStringLiteral("visibleToolBar"), &mainWindow)->isHidden());
+    QVERIFY(!factory->container(QStringLiteral("deletedToolBar"), &mainWindow));
+    QVERIFY(factory->container(QStringLiteral("file"), &mainWindow)); // File menu was created
+    QVERIFY(!factory->container(QStringLiteral("game"), &mainWindow)); // Game menu was not created
 
     // Now open KEditToolBar, just to check it doesn't crash.
     KEditToolBar editToolBar(factory);
     // KEditToolBar loads the stuff in showEvent...
     QShowEvent ev; qApp->sendEvent(&editToolBar, &ev);
     clickApply(&editToolBar);
-    QVERIFY(!factory->container("mainToolBar", &mainWindow));
-    QVERIFY(!factory->container("visibleToolBar", &mainWindow)->isHidden());
-    QVERIFY(!factory->container("deletedToolBar", &mainWindow));
-    QVERIFY(factory->container("file", &mainWindow));
-    QVERIFY(!factory->container("game", &mainWindow));
+    QVERIFY(!factory->container(QStringLiteral("mainToolBar"), &mainWindow));
+    QVERIFY(!factory->container(QStringLiteral("visibleToolBar"), &mainWindow)->isHidden());
+    QVERIFY(!factory->container(QStringLiteral("deletedToolBar"), &mainWindow));
+    QVERIFY(factory->container(QStringLiteral("file"), &mainWindow));
+    QVERIFY(!factory->container(QStringLiteral("game"), &mainWindow));
 
     mainWindow.close();
 }
@@ -884,7 +885,7 @@ void KXmlGui_UnitTest::testTopLevelSeparator()
         "</MenuBar>\n"
         "</gui>";
 
-    TestXmlGuiWindow mainWindow(xml);
+    TestXmlGuiWindow mainWindow(xml, "kxmlgui_unittest.rc");
     mainWindow.createGUI();
 
     checkActions(mainWindow.menuBar()->actions(), QStringList()
@@ -907,7 +908,7 @@ void KXmlGui_UnitTest::testMenuNames()
         "</MenuBar>\n"
         "</gui>";
 
-    TestXmlGuiWindow mainWindow(xml);
+    TestXmlGuiWindow mainWindow(xml, "kxmlgui_unittest.rc");
     mainWindow.createGUI();
 
     checkActions(mainWindow.menuBar()->actions(), QStringList()
@@ -920,7 +921,7 @@ void KXmlGui_UnitTest::testMenuNames()
 // We want a warning to be printed, but we don't want to see all menus from ui_standards.rc
 void KXmlGui_UnitTest::testMenusNoXmlFile()
 {
-    TestXmlGuiWindow mainWindow;
+    TestXmlGuiWindow mainWindow(QByteArray(), "nolocalfile_either.rc");
     mainWindow.createGUIBad();
 
     checkActions(mainWindow.menuBar()->actions(), QStringList()
@@ -943,8 +944,8 @@ void KXmlGui_UnitTest::testXMLFileReplacement()
     fileReplace.close();
 
     // finally, our local xml file has <ActionProperties/>
-    QFile fileLocal(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "testui.rc");
-    QVERIFY(fileLocal.open(QIODevice::WriteOnly));
+    QFile fileLocal(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + QStringLiteral("testui.rc"));
+    QVERIFY2(fileLocal.open(QIODevice::WriteOnly), qPrintable(fileLocal.fileName()));
     createXmlFile(fileLocal, 1, AddActionProperties);
     const QString filenameLocal = fileLocal.fileName();
     fileLocal.close();
@@ -954,23 +955,23 @@ void KXmlGui_UnitTest::testXMLFileReplacement()
     client.setXMLFilePublic(filenameOrig);
     QString xml = client.domDocument().toString();
     //qDebug() << xml;
-    QVERIFY(xml.contains("<Action name=\"print\""));
-    QVERIFY(!xml.contains("<Action name=\"home\""));
-    QVERIFY(!xml.contains("<ActionProperties>"));
+    QVERIFY(xml.contains(QStringLiteral("<Action name=\"print\"")));
+    QVERIFY(!xml.contains(QStringLiteral("<Action name=\"home\"")));
+    QVERIFY(!xml.contains(QStringLiteral("<ActionProperties>")));
 
     // now test the replacement (+ local file)
     client.replaceXMLFile(filenameReplace, filenameLocal);
     xml = client.domDocument().toString();
-    QVERIFY(!xml.contains("<Action name=\"print\""));
-    QVERIFY(xml.contains("<Action name=\"home\""));
-    QVERIFY(xml.contains("<ActionProperties>"));
+    QVERIFY(!xml.contains(QStringLiteral("<Action name=\"print\"")));
+    QVERIFY(xml.contains(QStringLiteral("<Action name=\"home\"")));
+    QVERIFY(xml.contains(QStringLiteral("<ActionProperties>")));
 
     // re-check after a reload
     client.reloadXML();
     QString reloadedXml = client.domDocument().toString();
-    QVERIFY(!reloadedXml.contains("<Action name=\"print\""));
-    QVERIFY(reloadedXml.contains("<Action name=\"home\""));
-    QVERIFY(reloadedXml.contains("<ActionProperties>"));
+    QVERIFY(!reloadedXml.contains(QStringLiteral("<Action name=\"print\"")));
+    QVERIFY(reloadedXml.contains(QStringLiteral("<Action name=\"home\"")));
+    QVERIFY(reloadedXml.contains(QStringLiteral("<ActionProperties>")));
 
     // Check what happens when the local file doesn't exist
     TestGuiClient client2;
@@ -978,9 +979,9 @@ void KXmlGui_UnitTest::testXMLFileReplacement()
     client2.replaceXMLFile(filenameReplace, filenameLocal);
     xml = client2.domDocument().toString();
     //qDebug() << xml;
-    QVERIFY(!xml.contains("<Action name=\"print\""));
-    QVERIFY(xml.contains("<Action name=\"home\"")); // modified toolbars
-    QVERIFY(!xml.contains("<ActionProperties>")); // but no local xml file
+    QVERIFY(!xml.contains(QStringLiteral("<Action name=\"print\"")));
+    QVERIFY(xml.contains(QStringLiteral("<Action name=\"home\""))); // modified toolbars
+    QVERIFY(!xml.contains(QStringLiteral("<ActionProperties>"))); // but no local xml file
 }
 
 void KXmlGui_UnitTest::testClientDestruction()   // #170806
@@ -1006,7 +1007,7 @@ void KXmlGui_UnitTest::testClientDestruction()   // #170806
                            "</MenuBar>\n"
                            "</gui>";
 
-    TestXmlGuiWindow mainWindow(hostXml);
+    TestXmlGuiWindow mainWindow(hostXml, "kxmlgui_unittest.rc");
     TestGuiClient *client = new TestGuiClient(xml);
     client->createActions(QStringList() << QStringLiteral("file_open") << QStringLiteral("file_quit"));
     mainWindow.insertChildClient(client);
@@ -1053,9 +1054,46 @@ void KXmlGui_UnitTest::testShortcuts()
     QAction* actionOpen = client.action("file_open");
     QAction* actionQuit = client.action("file_quit");
     QVERIFY(actionOpen && actionQuit);
-    QCOMPARE(actionOpen->shortcuts(), QList<QKeySequence>() << QKeySequence("Ctrl+O"));
+    QCOMPARE(actionOpen->shortcuts(), QList<QKeySequence>() << QKeySequence(QStringLiteral("Ctrl+O")));
     // #345411
-    QCOMPARE(actionQuit->shortcuts(), QList<QKeySequence>() << QKeySequence("Ctrl+Q") << QKeySequence("Ctrl+D"));
+    QCOMPARE(actionQuit->shortcuts(), QList<QKeySequence>() << QKeySequence(QStringLiteral("Ctrl+Q")) << QKeySequence(QStringLiteral("Ctrl+D")));
 
     factory.removeClient(&client);
 }
+
+void KXmlGui_UnitTest::testPopupMenuParent()
+{
+    const QByteArray xml =
+        "<?xml version = '1.0'?>\n"
+        "<!DOCTYPE gui SYSTEM \"kpartgui.dtd\">\n"
+        "<gui version=\"1\" name=\"foo\" >\n"
+        "<Menu name=\"foo\"><text>Foo</text></Menu>\n"
+        "</gui>";
+
+    TestXmlGuiWindow mainWindow(xml, "kxmlgui_unittest.rc");
+    mainWindow.createGUI();
+
+    auto popupMenu = mainWindow.menuByName(QStringLiteral("foo"));
+    QVERIFY(popupMenu);
+    QCOMPARE(popupMenu->parent(), &mainWindow);
+}
+
+void KXmlGui_UnitTest::testSpecificApplicationLanguageQLocale()
+{
+    const QLocale originalSystemLocale = QLocale::system();
+
+    KDEPrivate::setApplicationSpecificLanguage("ru_RU");
+    KDEPrivate::initializeLanguages();
+
+    QCOMPARE(QLocale::system().language(), QLocale::Russian);
+
+    KDEPrivate::setApplicationSpecificLanguage("wa");
+    KDEPrivate::initializeLanguages();
+
+    QCOMPARE(QLocale::system().language(), QLocale::Walloon);
+
+    KDEPrivate::setApplicationSpecificLanguage(QByteArray());
+    KDEPrivate::initializeLanguages();
+
+    QCOMPARE(QLocale::system(), originalSystemLocale);
+}
