@@ -40,7 +40,7 @@ KAboutApplicationPersonModel::KAboutApplicationPersonModel(const QList< KAboutPe
     , m_providerUrl(providerUrl)
 {
     if (m_providerUrl.isEmpty()) {
-        m_providerUrl = QStringLiteral("https://api.opendesktop.org/v1/");
+        m_providerUrl = QStringLiteral("https://api.kde-look.org/ocs/v1/");
     }
 
     bool hasOcsUsernames = false;
@@ -265,9 +265,6 @@ void KAboutApplicationPersonModel::onAvatarJobFinished(QNetworkReply *reply)
 
 void KAboutApplicationPersonModel::fetchOcsLinkIcons(int personProfileListIndex)
 {
-    KAboutApplicationPersonProfile profile = m_profileList.value(personProfileListIndex);
-    QList< KAboutApplicationPersonProfileOcsLink > ocsLinks = profile.ocsLinks();
-
     KAboutApplicationPersonIconsJob *job =
         new KAboutApplicationPersonIconsJob(this, personProfileListIndex);
     connect(job, SIGNAL(finished(KAboutApplicationPersonIconsJob*)),
