@@ -19,8 +19,8 @@
 
 #include "kbugreport.h"
 
-#include <QtCore/QProcess>
-#include <QtCore/QCoreApplication>
+#include <QProcess>
+#include <QCoreApplication>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QLayout>
@@ -105,8 +105,8 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(this);
     buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-    connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
     d->m_aboutData = aboutData;
     d->m_process = nullptr;
