@@ -23,15 +23,15 @@
 
 #include "kkeysequencewidget.h"
 #include "kkeysequencewidget_p.h"
+#include "debug.h"
 
 #include <QAction>
 #include <QKeyEvent>
 #include <QTimer>
-#include <QtCore/QHash>
+#include <QHash>
 #include <QHBoxLayout>
 #include <QToolButton>
 #include <QApplication>
-#include <QDebug>
 
 #include <klocalizedstring.h>
 #include <kmessagebox.h>
@@ -42,13 +42,6 @@
 
 #include "kactioncollection.h"
 
-#if HAVE_GLOBALACCEL && QT_VERSION < QT_VERSION_CHECK(5, 6, 0)
-static uint qHash(const QKeySequence &seq)
-{
-    return qHash(seq.toString());
-}
-#endif
-
 class KKeySequenceWidgetPrivate
 {
 public:
@@ -63,25 +56,25 @@ public:
     void startRecording();
 
     /**
-     * Conflicts the key sequence @a seq with a current standard
+     * Conflicts the key sequence @p seq with a current standard
      * shortcut?
      */
     bool conflictWithStandardShortcuts(const QKeySequence &seq);
 
     /**
-     * Conflicts the key sequence @a seq with a current local
+     * Conflicts the key sequence @p seq with a current local
      * shortcut?
      */
     bool conflictWithLocalShortcuts(const QKeySequence &seq);
 
     /**
-     * Conflicts the key sequence @a seq with a current global
+     * Conflicts the key sequence @p seq with a current global
      * shortcut?
      */
     bool conflictWithGlobalShortcuts(const QKeySequence &seq);
 
     /**
-     * Get permission to steal the shortcut @seq from the standard shortcut @a std.
+     * Get permission to steal the shortcut @seq from the standard shortcut @p std.
      */
     bool stealStandardShortcut(KStandardShortcut::StandardShortcut std, const QKeySequence &seq);
 
@@ -199,9 +192,9 @@ public:
 
 KKeySequenceWidgetPrivate::KKeySequenceWidgetPrivate(KKeySequenceWidget *q)
     : q(q)
-    , layout(NULL)
-    , keyButton(NULL)
-    , clearButton(NULL)
+    , layout(nullptr)
+    , keyButton(nullptr)
+    , clearButton(nullptr)
     , allowModifierless(false)
     , nKey(0)
     , modifierKeys(0)
@@ -260,8 +253,8 @@ KKeySequenceWidget::KKeySequenceWidget(QWidget *parent)
 {
     d->init();
     setFocusProxy(d->keyButton);
-    connect(d->keyButton, SIGNAL(clicked()), this, SLOT(captureKeySequence()));
-    connect(d->clearButton, SIGNAL(clicked()), this, SLOT(clearKeySequence()));
+    connect(d->keyButton, &KKeySequenceButton::clicked, this, &KKeySequenceWidget::captureKeySequence);
+    connect(d->clearButton, &QToolButton::clicked, this, &KKeySequenceWidget::clearKeySequence);
     connect(&d->modifierlessTimeout, SIGNAL(timeout()), this, SLOT(doneRecording()));
     //TODO: how to adopt style changes at runtime?
     /*QFont modFont = d->clearButton->font();
@@ -403,7 +396,7 @@ void KKeySequenceWidget::applyStealShortcut()
 
         // The following code will find the action we are about to
         // steal from and save it's actioncollection.
-        KActionCollection *parentCollection = 0;
+        KActionCollection *parentCollection = nullptr;
         foreach (KActionCollection *collection, d->checkActionCollections) {
             if (collection->actions().contains(stealAction)) {
                 parentCollection = collection;
@@ -434,7 +427,7 @@ void KKeySequenceWidgetPrivate::startRecording()
     keyButton->grabKeyboard();
 
     if (!QWidget::keyboardGrabber()) {
-        qWarning() << "Failed to grab the keyboard! Most likely qt's nograb option is active";
+        qCWarning(DEBUG_KXMLGUI) << "Failed to grab the keyboard! Most likely qt's nograb option is active";
     }
 
     keyButton->setDown(true);
@@ -646,26 +639,29 @@ void KKeySequenceWidgetPrivate::updateShortcutDisplay()
             if (!s.isEmpty()) {
                 s.append(QLatin1Char(','));
             }
-            if (modifierKeys & Qt::META) {
-                s += KKeyServer::modToStringUser(Qt::META) + QLatin1Char('+');
+            if (modifierKeys & Qt::MetaModifier) {
+                s += KKeyServer::modToStringUser(Qt::MetaModifier) + QLatin1Char('+');
             }
 #if defined(Q_OS_MAC)
-            if (modifierKeys & Qt::ALT) {
-                s += KKeyServer::modToStringUser(Qt::ALT) + QLatin1Char('+');
+            if (modifierKeys & Qt::AltModifier) {
+                s += KKeyServer::modToStringUser(Qt::AltModifier) + QLatin1Char('+');
             }
-            if (modifierKeys & Qt::CTRL) {
-                s += KKeyServer::modToStringUser(Qt::CTRL) + QLatin1Char('+');
+            if (modifierKeys & Qt::ControlModifier) {
+                s += KKeyServer::modToStringUser(Qt::ControlModifier) + QLatin1Char('+');
             }
 #else
-            if (modifierKeys & Qt::CTRL) {
-                s += KKeyServer::modToStringUser(Qt::CTRL) + QLatin1Char('+');
+            if (modifierKeys & Qt::ControlModifier) {
+                s += KKeyServer::modToStringUser(Qt::ControlModifier) + QLatin1Char('+');
             }
-            if (modifierKeys & Qt::ALT) {
-                s += KKeyServer::modToStringUser(Qt::ALT) + QLatin1Char('+');
+            if (modifierKeys & Qt::AltModifier) {
+                s += KKeyServer::modToStringUser(Qt::AltModifier) + QLatin1Char('+');
             }
 #endif
-            if (modifierKeys & Qt::SHIFT) {
-                s += KKeyServer::modToStringUser(Qt::SHIFT) + QLatin1Char('+');
+            if (modifierKeys & Qt::ShiftModifier) {
+                s += KKeyServer::modToStringUser(Qt::ShiftModifier) + QLatin1Char('+');
+            }
+            if (modifierKeys & Qt::KeypadModifier) {
+                s += KKeyServer::modToStringUser(Qt::KeypadModifier) + QLatin1Char('+');
             }
 
         } else if (nKey == 0) {
@@ -724,10 +720,11 @@ void KKeySequenceButton::keyPressEvent(QKeyEvent *e)
         KMessageBox::sorry(this,
                            i18n("The key you just pressed is not supported by Qt."),
                            i18n("Unsupported Key"));
-        return d->cancelRecording();
+        d->cancelRecording();
+        return;
     }
 
-    uint newModifiers = e->modifiers() & (Qt::SHIFT | Qt::CTRL | Qt::ALT | Qt::META);
+    uint newModifiers = e->modifiers() & (Qt::ShiftModifier | Qt::ControlModifier | Qt::AltModifier | Qt::MetaModifier | Qt::KeypadModifier);
 
     //don't have the return or space key appear as first key of the sequence when they
     //were pressed to start editing - catch and them and imitate their effect
@@ -740,7 +737,8 @@ void KKeySequenceButton::keyPressEvent(QKeyEvent *e)
 
     // We get events even if recording isn't active.
     if (!d->isRecording) {
-        return QPushButton::keyPressEvent(e);
+        QPushButton::keyPressEvent(e);
+        return;
     }
 
     e->accept();
@@ -806,12 +804,13 @@ void KKeySequenceButton::keyReleaseEvent(QKeyEvent *e)
     }
 
     if (!d->isRecording) {
-        return QPushButton::keyReleaseEvent(e);
+        QPushButton::keyReleaseEvent(e);
+        return;
     }
 
     e->accept();
 
-    uint newModifiers = e->modifiers() & (Qt::SHIFT | Qt::CTRL | Qt::ALT | Qt::META);
+    uint newModifiers = e->modifiers() & (Qt::ShiftModifier | Qt::ControlModifier | Qt::AltModifier | Qt::MetaModifier | Qt::KeypadModifier);
 
     //if a modifier that belongs to the shortcut was released...
     if ((newModifiers & d->modifierKeys) < d->modifierKeys) {
@@ -860,4 +859,3 @@ bool KKeySequenceWidgetPrivate::isOkWhenModifierless(int keyQt)
 }
 
 #include "moc_kkeysequencewidget.cpp"
-#include "moc_kkeysequencewidget_p.cpp"
